@@ -15,4 +15,4 @@ pub const BUTTON_RELEASED_EVENT_CODE: u16 = 0x0008;
 
 pub const INTERNAL_SYSTEM_TICK_EVENT_CODE: u16 = 0x0009;
 
-pub const PROGRAMMER_START_EVENT_PROCESSOR_UPLOAD_EVENT_CODE: u16 = 0x000a;
+pub const PROGRAMMER_START_CONFIG_UPLOAD_EVENT_CODE: u16 = 0x000a;
