@@ -10,12 +10,11 @@ use crate::protocol::BROADCAST_ADDRESS;
 #[derive(Debug, PartialEq)]
 pub struct ProgrammerHelloEvent {
     pub programmer_address: u16,
-    pub firmware_version: u32,
 }
 
 impl ConvertPacket<ProgrammerHelloEvent> for ProgrammerHelloEvent {
     fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError> {
-        if packet.data.len() != 8 {
+        if packet.data.len() != 4 {
             return Err(ConvertPacketError::WrongSize);
         }
 
@@ -29,12 +28,8 @@ impl ConvertPacket<ProgrammerHelloEvent> for ProgrammerHelloEvent {
         }
 
         let programmer_address = u16::from_be_bytes(packet.data[2..=3].try_into().unwrap());
-        let firmware_version = u32::from_be_bytes(packet.data[4..=7].try_into().unwrap());
 
-        Ok(ProgrammerHelloEvent {
-            programmer_address,
-            firmware_version,
-        })
+        Ok(ProgrammerHelloEvent { programmer_address })
     }
 
     fn to_packet(&self) -> Packet {
@@ -48,10 +43,6 @@ impl ConvertPacket<ProgrammerHelloEvent> for ProgrammerHelloEvent {
             data.push(*byte);
         }
 
-        for byte in u32::to_be_bytes(self.firmware_version).iter() {
-            data.push(*byte);
-        }
-
         Packet {
             is_error: false,
             device_address: BROADCAST_ADDRESS,
@@ -64,13 +55,12 @@ impl ConvertPacket<ProgrammerHelloEvent> for ProgrammerHelloEvent {
 pub struct ProgrammerStartUploadEvent {
     pub receiver_address: u16,
     pub programmer_address: u16,
-    pub new_firmware_version: u32,
     pub firmware_size: u32,
 }
 
 impl ConvertPacket<ProgrammerStartUploadEvent> for ProgrammerStartUploadEvent {
     fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError> {
-        if packet.data.len() != 12 {
+        if packet.data.len() != 8 {
             return Err(ConvertPacketError::WrongSize);
         }
 
@@ -86,13 +76,11 @@ impl ConvertPacket<ProgrammerStartUploadEvent> for ProgrammerStartUploadEvent {
 
         let receiver_address = packet.device_address;
         let programmer_address = u16::from_be_bytes(packet.data[2..=3].try_into().unwrap());
-        let new_firmware_version = u32::from_be_bytes(packet.data[4..=7].try_into().unwrap());
-        let firmware_size = u32::from_be_bytes(packet.data[8..=11].try_into().unwrap());
+        let firmware_size = u32::from_be_bytes(packet.data[4..=7].try_into().unwrap());
 
         Ok(ProgrammerStartUploadEvent {
             receiver_address,
             programmer_address,
-            new_firmware_version,
             firmware_size,
         })
     }
@@ -108,10 +96,6 @@ impl ConvertPacket<ProgrammerStartUploadEvent> for ProgrammerStartUploadEvent {
             data.push(*byte);
         }
 
-        for byte in u32::to_be_bytes(self.new_firmware_version).iter() {
-            data.push(*byte);
-        }
-
         for byte in u32::to_be_bytes(self.firmware_size).iter() {
             data.push(*byte);
         }
@@ -125,13 +109,13 @@ impl ConvertPacket<ProgrammerStartUploadEvent> for ProgrammerStartUploadEvent {
 }
 
 #[derive(Debug, PartialEq)]
-pub struct ProgrammerStartEventProcessorUploadEvent {
+pub struct ProgrammerStartConfigUploadEvent {
     pub receiver_address: u16,
     pub programmer_address: u16,
     pub data_len: u32,
 }
 
-impl ConvertPacket<ProgrammerStartEventProcessorUploadEvent> for ProgrammerStartEventProcessorUploadEvent {
+impl ConvertPacket<ProgrammerStartConfigUploadEvent> for ProgrammerStartConfigUploadEvent {
     fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError> {
         if packet.data.len() != 8 {
             return Err(ConvertPacketError::WrongSize);
@@ -142,7 +126,7 @@ impl ConvertPacket<ProgrammerStartEventProcessorUploadEvent> for ProgrammerStart
         }
 
         if u16::from_be_bytes(packet.data[0..=1].try_into().unwrap())
-            != PROGRAMMER_START_EVENT_PROCESSOR_UPLOAD_EVENT_CODE
+            != PROGRAMMER_START_CONFIG_UPLOAD_EVENT_CODE
         {
             return Err(ConvertPacketError::Event(EventError::WrongEventType));
         }
@@ -151,7 +135,7 @@ impl ConvertPacket<ProgrammerStartEventProcessorUploadEvent> for ProgrammerStart
         let programmer_address = u16::from_be_bytes(packet.data[2..=3].try_into().unwrap());
         let data_len = u32::from_be_bytes(packet.data[4..=7].try_into().unwrap());
 
-        Ok(ProgrammerStartEventProcessorUploadEvent {
+        Ok(ProgrammerStartConfigUploadEvent {
             receiver_address,
             programmer_address,
             data_len,
@@ -161,7 +145,7 @@ impl ConvertPacket<ProgrammerStartEventProcessorUploadEvent> for ProgrammerStart
     fn to_packet(&self) -> Packet {
         let mut data = vec![];
 
-        for byte in u16::to_be_bytes(PROGRAMMER_START_EVENT_PROCESSOR_UPLOAD_EVENT_CODE).iter() {
+        for byte in u16::to_be_bytes(PROGRAMMER_START_CONFIG_UPLOAD_EVENT_CODE).iter() {
             data.push(*byte);
         }
 
